"use strict";
const common_vendor = require("../../common/vendor.js");
const sheep_config_index = require("../config/index.js");
const sheep_store_index = require("../store/index.js");
const sheep_platform_index = require("../platform/index.js");
const sheep_hooks_useModal = require("../hooks/useModal.js");
const sheep_api_member_auth = require("../api/member/auth.js");
const options = {
  // 显示操作成功消息 默认不显示
  showSuccess: false,
  // 成功提醒 默认使用后端返回值
  successMsg: "",
  // 显示失败消息 默认显示
  showError: true,
  // 失败提醒 默认使用后端返回信息
  errorMsg: "",
  // 显示请求时loading模态框 默认显示
  showLoading: true,
  // loading提醒文字
  loadingMsg: "加载中",
  // 需要授权才能请求 默认放开
  auth: false
  // ...
};
let LoadingInstance = {
  target: null,
  count: 0
};
function closeLoading() {
  if (LoadingInstance.count > 0)
    LoadingInstance.count--;
  if (LoadingInstance.count === 0)
    common_vendor.index.hideLoading();
}
const http = new common_vendor.Request({
  baseURL: sheep_config_index.baseUrl + sheep_config_index.apiPath,
  timeout: 8e3,
  method: "GET",
  header: {
    Accept: "text/json",
    "Content-Type": "application/json;charset=UTF-8",
    platform: sheep_platform_index._platform.name
  },
  custom: options
});
http.interceptors.request.use(
  (config) => {
    if (config.custom.auth && !sheep_store_index.$store("user").isLogin) {
      sheep_hooks_useModal.showAuthModal();
      return Promise.reject();
    }
    if (config.custom.showLoading) {
      LoadingInstance.count++;
      LoadingInstance.count === 1 && common_vendor.index.showLoading({
        title: config.custom.loadingMsg,
        mask: true,
        fail: () => {
          common_vendor.index.hideLoading();
        }
      });
    }
    const token = getAccessToken();
    if (token) {
      config.header["Authorization"] = token;
    }
    config.header["Accept"] = "*/*";
    config.header["tenant-id"] = "1";
    config.header["terminal"] = "20";
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);
http.interceptors.response.use(
  (response) => {
    var _a, _b;
    if (response.config.url.indexOf("/member/auth/") >= 0 && ((_b = (_a = response.data) == null ? void 0 : _a.data) == null ? void 0 : _b.accessToken)) {
      sheep_store_index.$store("user").setToken(response.data.data.accessToken, response.data.data.refreshToken);
    }
    response.config.custom.showLoading && closeLoading();
    if (response.data.code !== 0) {
      if (response.data.code === 401) {
        return refreshToken(response.config);
      }
      if (response.config.custom.showError) {
        common_vendor.index.showToast({
          title: response.data.msg || "服务器开小差啦,请稍后再试~",
          icon: "none",
          mask: true
        });
      }
    }
    if (response.config.custom.showSuccess && response.config.custom.successMsg !== "" && response.data.code === 0) {
      common_vendor.index.showToast({
        title: response.config.custom.successMsg,
        icon: "none"
      });
    }
    return Promise.resolve(response.data);
  },
  (error) => {
    var _a;
    const userStore = sheep_store_index.$store("user");
    const isLogin = userStore.isLogin;
    let errorMessage = "网络请求出错";
    if (error !== void 0) {
      switch (error.statusCode) {
        case 400:
          errorMessage = "请求错误";
          break;
        case 401:
          errorMessage = isLogin ? "您的登陆已过期" : "请先登录";
          break;
        case 403:
          errorMessage = "拒绝访问";
          break;
        case 404:
          errorMessage = "请求出错";
          break;
        case 408:
          errorMessage = "请求超时";
          break;
        case 429:
          errorMessage = "请求频繁, 请稍后再访问";
          break;
        case 500:
          errorMessage = "服务器开小差啦,请稍后再试~";
          break;
        case 501:
          errorMessage = "服务未实现";
          break;
        case 502:
          errorMessage = "网络错误";
          break;
        case 503:
          errorMessage = "服务不可用";
          break;
        case 504:
          errorMessage = "网络超时";
          break;
        case 505:
          errorMessage = "HTTP 版本不受支持";
          break;
      }
      if (error.errMsg.includes("timeout"))
        errorMessage = "请求超时";
    }
    if (error && error.config) {
      if (error.config.custom.showError === false) {
        common_vendor.index.showToast({
          title: ((_a = error.data) == null ? void 0 : _a.msg) || errorMessage,
          icon: "none",
          mask: true
        });
      }
      error.config.custom.showLoading && closeLoading();
    }
    return false;
  }
);
let requestList = [];
let isRefreshToken = false;
const refreshToken = async (config) => {
  if (config.url.indexOf("/member/auth/refresh-token") >= 0) {
    return Promise.reject("error");
  }
  if (!isRefreshToken) {
    isRefreshToken = true;
    const refreshToken2 = getRefreshToken();
    if (!refreshToken2) {
      return handleAuthorized();
    }
    try {
      const refreshTokenResult = await sheep_api_member_auth.AuthUtil.refreshToken(refreshToken2);
      if (refreshTokenResult.code !== 0) {
        throw new Error("刷新令牌失败");
      }
      config.header.Authorization = "Bearer " + getAccessToken();
      requestList.forEach((cb) => {
        cb();
      });
      requestList = [];
      return request(config);
    } catch (e) {
      requestList.forEach((cb) => {
        cb();
      });
      return handleAuthorized();
    } finally {
      requestList = [];
      isRefreshToken = false;
    }
  } else {
    return new Promise((resolve) => {
      requestList.push(() => {
        config.header.Authorization = "Bearer " + getAccessToken();
        resolve(request(config));
      });
    });
  }
};
const handleAuthorized = () => {
  const userStore = sheep_store_index.$store("user");
  userStore.logout(true);
  sheep_hooks_useModal.showAuthModal();
  return Promise.reject({
    code: 401,
    msg: userStore.isLogin ? "您的登陆已过期" : "请先登录"
  });
};
const getAccessToken = () => {
  return common_vendor.index.getStorageSync("token");
};
const getRefreshToken = () => {
  return common_vendor.index.getStorageSync("refresh-token");
};
const request = (config) => {
  return http.middleware(config);
};
const request$1 = request;
exports.request = request$1;
